pyxmpp.jabberd.component

Package pyxmpp :: Package jabberd :: Module component |
[hide private]

# Module component

source code

Jabberd external component interface (jabber:component:accept).

Normative reference:
  - JEP 114

Classes | [hide private]
| Component Jabber external component ("jabber:component:accept" protocol) interface implementation.

Variables | [hide private]
| __revision__ = ``'``$Id: component.py 714 2010-04-05 10:20:10Z jaj``...``
| __package__ = ``'``pyxmpp.jabberd``'``

Imports: threading, logging, ComponentStream, from_utf8, DiscoItems, DiscoInfo, DiscoIdentity, Stanza

Variables Details | [hide private]

  ### __revision__ Value:
      '$Id: component.py 714 2010-04-05 10:20:10Z jajcus $'